@@ -124,7 +124,7 @@ class BreakBuild:
         print(f"Mitigated count: {mitigated}   Total count: {total}")
         remediation_rate_value = self._get_percentage(mitigated / total)
 
-        risk_threshold = self.threshold["REMEDIATION_RATE"]
+        risk_threshold = self._get_remediation_rate_threshold(total)
         self.remediation_rate = remediation_rate_value
 
         if remediation_rate_value >= (risk_threshold + 5):
@@ -151,6 +151,13 @@ class BreakBuild:
             )
             self.break_build = True
 
+    def _get_remediation_rate_threshold(self, total):
+        remediation_rate = self.threshold["REMEDIATION_RATE"]
+        for key in sorted(remediation_rate.keys(), key=lambda x: int(x) if x.isdigit() else float('inf')):
+            if key.isdigit() and total <= int(key):
+                return remediation_rate[key]
+        return remediation_rate["other"]
+
     def _get_percentage(self, decimal):
         return round(decimal * 100, 3)
 
@@ -186,14 +193,21 @@ class BreakBuild:
                     or (report.id and report.id == exclusion.id)
                     or (report.vm_id and exclusion.id in report.vm_id)
                 ) and ((exclusion.where in report.where) or (exclusion.where == "all")):
-                    exclude = True
-                    exclusion_copy = copy.deepcopy(exclusion)
-                    exclusion_copy.vm_id = report.vm_id
-                    exclusion_copy.vm_id_url = report.vm_id_url
-                    exclusion_copy.service = report.service
-                    exclusion_copy.tags = report.tags
-                    applied_exclusions.append(exclusion_copy)
-                    break
+                    if not exclusion.check_in_desc:
+                        exclude = True
+                    else:
+                        for item in exclusion.check_in_desc:
+                            if item in report.vul_description:
+                                exclude = True
+                                break
+                    if exclude:
+                        exclusion_copy = copy.deepcopy(exclusion)
+                        exclusion_copy.vm_id = report.vm_id
+                        exclusion_copy.vm_id_url = report.vm_id_url
+                        exclusion_copy.service = report.service
+                        exclusion_copy.tags = report.tags
+                        applied_exclusions.append(exclusion_copy)
+                        break
             if not exclude:
                 report.reason = "Remediation Rate"
                 filtered_reports.append(report)
